@@ -1,7 +1,6 @@
-use super::{api, ProjectTopicName};
+use super::{api, ProjectTopicName, PubSubRetryCheck};
 use crate::{
     auth::grpc::{AuthGrpcService, OAuthTokenSource},
-    grpc::StatusCodeSet,
     retry_policy::{exponential_backoff, ExponentialBackoff, RetryOperation, RetryPolicy},
 };
 use futures::{future::BoxFuture, ready, stream, Sink, SinkExt};
@@ -113,7 +112,7 @@ impl From<SinkError<Infallible>> for tonic::Status {
 ///
 /// ## Errors and Retrying
 /// By default, the sink constructed by `publish_topic_sink` will re-attempt certain failed publish
-/// requests by using an [exponential backoff] policy, for typically [retriable status codes] and
+/// requests by using an [exponential backoff] policy, for typically retriable status codes and
 /// up to a fixed retry count. This behavior can be controlled with the [`with_retry_policy`]
 /// method, which will apply a given retry policy to the sink's publish attempts. Should a publish
 /// request return an error, the sink will internally try again based on the retry policy, and may
@@ -134,13 +133,12 @@ impl From<SinkError<Infallible>> for tonic::Status {
 /// [resource limits]: https://cloud.google.com/pubsub/quotas#resource_limits
 /// [`send_all`]: futures::SinkExt::send_all
 /// [exponential backoff]: crate::retry_policy::ExponentialBackoff
-/// [retriable status codes]: crate::pubsub::DEFAULT_RETRY_CODES
 /// [`with_retry_policy`]: PublishTopicSink::with_retry_policy
 /// [`with_response_sink`]: PublishTopicSink::with_response_sink
 #[pin_project(project=PublishTopicSinkProjection)]
 pub struct PublishTopicSink<
     C = crate::DefaultConnector,
-    Retry = ExponentialBackoff<StatusCodeSet>,
+    Retry = ExponentialBackoff<PubSubRetryCheck>,
     ResponseSink: Sink<api::PubsubMessage> = Drain,
 > {
     /// the underlying client used to execute the requests
@@ -176,7 +174,7 @@ enum FlushState<ResponseSink: Sink<api::PubsubMessage>> {
     Flushing(#[pin] BoxFuture<'static, FlushOutput<ResponseSink, ResponseSink::Error>>),
 }
 
-impl<C> PublishTopicSink<C, ExponentialBackoff<StatusCodeSet>, Drain> {
+impl<C> PublishTopicSink<C, ExponentialBackoff<PubSubRetryCheck>, Drain> {
     /// Create a new `PublishTopicSink` with the default retry policy and no response sink
     pub(super) fn new(client: ApiPublisherClient<C>, topic: ProjectTopicName) -> Self
     where
@@ -187,7 +185,7 @@ impl<C> PublishTopicSink<C, ExponentialBackoff<StatusCodeSet>, Drain> {
             buffer: PublishBuffer::new(String::from(topic)),
             flush_state: FlushState::NotFlushing(futures::sink::drain()),
             retry_policy: ExponentialBackoff::new(
-                crate::pubsub::DEFAULT_RETRY_CODES,
+                PubSubRetryCheck::default(),
                 exponential_backoff::Config::default(),
             ),
             _pin: std::marker::PhantomPinned,
@@ -695,9 +693,7 @@ mod test {
         // is made (then it will error). That's good enough for testing certain functionality
         // that doesn't require the requests themselves, like validity checking
         ApiPublisherClient::new(crate::auth::grpc::oauth_grpc(
-            tonic::transport::channel::Endpoint::from_static("https://localhost")
-                .connect_lazy()
-                .unwrap(),
+            tonic::transport::channel::Endpoint::from_static("https://localhost").connect_lazy(),
             None,
             vec![],
         ))
